@@ -23,22 +23,25 @@ from badi_utils.logging import log
 from badi_utils.responses import ResponseOk, ResponseNotOk
 from badi_utils.utils import random_with_N_digits, permissions_json
 from rest_framework_simplejwt.views import TokenRefreshView
-from badi_user.api.serializers import UserSerializer, GroupSerializer, MemberSerializer
-from badi_user.filter import UserListFilter, MemberListFilter
-from badi_user.models import Token
+from badi_user.api.serializers import UserSerializer, GroupSerializer, MemberSerializer, LogSerializer
+from badi_user.filter import UserListFilter, MemberListFilter, LogFilter
+from badi_user.models import Token, Log
 from django.utils.translation import gettext_lazy as _
 from badi_utils.sms import IpPanelSms
 from django.contrib.auth import get_user_model
 from django.conf import settings
 
+MONTH_NAMES = ["Jan", "Feb", "Mar", "Apr", "Maj", "Jun", "Jul", "Aug", "Sep", "Okt", "Nov", "Dec"]
 BADI_AUTH_CONFIG = getattr(settings, "BADI_AUTH_CONFIG", {})
 
 User = get_user_model()
 
 
 class UserViewSet(DynamicModelApi):
-    columns = ['id', 'username', 'first_name', 'last_name', 'mobile_number', 'is_admin', 'is_active', ]
-    order_columns = ['id', 'username', 'first_name', 'last_name', 'mobile_number', 'is_admin', 'is_active', ]
+    columns = ['id', 'picture', 'username', 'first_name', 'last_name', 'mobile_number', 'is_admin', 'is_active',
+               'email', ]
+    order_columns = ['id', 'picture', 'username', 'first_name', 'last_name', 'mobile_number', 'is_admin', 'is_active',
+                     'email', ]
     model = User
     queryset = User.objects.filter(is_admin=True)
     serializer_class = UserSerializer
@@ -474,6 +477,34 @@ class MemberViewSet(DynamicModelApi):
 
         return Response(serializer.data)
 
+    @action(methods=['get'], detail=False)
+    def chart(self, request, *args, **kwargs):
+        today = datetime.datetime.today()
+        start_of_month = datetime.datetime.today()
+        members = User.members()
+        data = {
+            "data-new-members-today": members.filter(date_joined=today).count(),
+            "data-new-members-week": members.filter(date_joined__gte=today - datetime.timedelta(days=7)).count(),
+            "data-all-personnels-count": User.personnels().count(),
+            "data-all-members-count": members.count(),
+            "data": [{
+                'name': "New Personnel's",
+                'data': [User.objects.filter(is_personnel=True,
+                                             date_joined__month=(
+                                                     start_of_month - datetime.timedelta(days=30 * x)).month,
+                                             date_joined__year=(start_of_month - datetime.timedelta(days=30 * x)).year
+                                             ).count() for x in range(7)]
+            }, {
+                'name': 'New Members',
+                'data': [members.filter(
+                    date_joined__month=(start_of_month - datetime.timedelta(days=30 * x)).month,
+                    date_joined__year=(start_of_month - datetime.timedelta(days=30 * x)).year
+                ).count() for x in range(7)]
+            }],
+            'labels': [MONTH_NAMES[(start_of_month - datetime.timedelta(days=30 * x)).month - 1] for x in range(7)]
+        }
+        return Response(data)
+
     @action(methods=['put'], detail=False)
     def change_password(self, request, *args, **kwargs):
         old_password = self.request.data.get('old_password')
@@ -519,3 +550,33 @@ class MemberViewSet(DynamicModelApi):
         if column == 'transactions__count':
             return row.transactions.count()
         return super().render_column(row, column)
+
+
+class LogViewSet(DynamicModelApi):
+    model = Log
+    serializer_class = LogSerializer
+    queryset = Log.objects.all()
+    filterset_class = LogFilter
+    disables_views = ['create', 'destroy', 'update']
+    custom_perms = {
+        'datatable': 'user.can_log',
+        'user': 'user.can_user',
+        'self': True,
+    }
+
+    @action(methods=['get'], detail=False)
+    def self(self, request, *args, **kwargs):
+        return self.list(request, *args, **kwargs)
+
+    @action(methods=['post'], detail=False, url_path='user/(?P<pk>[^/.]+)')
+    def user(self, request, *args, **kwargs):
+        return self.datatable(request, *args, **kwargs)
+
+    def filter_queryset(self, qs):
+        if self.action == 'self':
+            return qs.filter(user=self.request.user)
+        if self.action == 'user':
+            return qs.filter(user_id=self.kwargs['pk'])
+        if self.action == 'datatable':
+            return LogFilter(self.request.data).qs
+        return super().filter_queryset(qs)
